# MkDocs Zettelkasten

This is a [Zettelkasten](https://zettelkasten.de) theme and plugin for MkDocs. It renders the MkDocs pages as cards (zettels).

For more information, head on over to [the documentation](https://tbouska.github.io/mkdocs-zettelkasten)
